/****************************************************************************
** Meta object code from reading C++ file 'partmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../mimetreeparser-26.04.2/src/core/partmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'partmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9PartModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PartModel::qt_create_metaobjectdata<qt_meta_tag_ZN9PartModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PartModel",
        "showHtmlChanged",
        "",
        "trimMailChanged",
        "containsHtmlChanged",
        "showHtml",
        "containsHtml",
        "trimMail",
        "isTrimmed",
        "Types",
        "Error",
        "Encapsulated",
        "Ical",
        "Plain",
        "None",
        "Html",
        "SecurityLevel",
        "Unknow",
        "Good",
        "NotSoGood",
        "Bad"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showHtmlChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trimMailChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'containsHtmlChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'showHtml'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'containsHtml'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'trimMail'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isTrimmed'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Types'
        QtMocHelpers::EnumData<enum Types>(9, 9, QMC::EnumIsScoped).add({
            {   10, Types::Error },
            {   11, Types::Encapsulated },
            {   12, Types::Ical },
            {   13, Types::Plain },
            {   14, Types::None },
            {   15, Types::Html },
        }),
        // enum 'SecurityLevel'
        QtMocHelpers::EnumData<enum SecurityLevel>(16, 16, QMC::EnumFlags{}).add({
            {   17, SecurityLevel::Unknow },
            {   18, SecurityLevel::Good },
            {   19, SecurityLevel::NotSoGood },
            {   20, SecurityLevel::Bad },
        }),
    };
    return QtMocHelpers::metaObjectData<PartModel, qt_meta_tag_ZN9PartModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PartModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PartModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PartModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9PartModelE_t>.metaTypes,
    nullptr
} };

void PartModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PartModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showHtmlChanged(); break;
        case 1: _t->trimMailChanged(); break;
        case 2: _t->containsHtmlChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PartModel::*)()>(_a, &PartModel::showHtmlChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PartModel::*)()>(_a, &PartModel::trimMailChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PartModel::*)()>(_a, &PartModel::containsHtmlChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->showHtml(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->containsHtml(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->trimMail(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isTrimmed(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShowHtml(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setTrimMail(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PartModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PartModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PartModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int PartModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void PartModel::showHtmlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PartModel::trimMailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PartModel::containsHtmlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN13SignatureInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto SignatureInfo::qt_create_metaobjectdata<qt_meta_tag_ZN13SignatureInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignatureInfo",
        "keyId",
        "keyMissing",
        "keyRevoked",
        "keyExpired",
        "sigExpired",
        "crlMissing",
        "crlTooOld",
        "signer",
        "signerMailAddresses",
        "signatureIsGood",
        "isCompliant",
        "keyTrust",
        "signatureSummary",
        "GpgME::Signature::Summary"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'keyId'
        QtMocHelpers::PropertyData<QByteArray>(1, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyMissing'
        QtMocHelpers::PropertyData<bool>(2, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyRevoked'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyExpired'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sigExpired'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'crlMissing'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'crlTooOld'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'signer'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'signerMailAddresses'
        QtMocHelpers::PropertyData<QStringList>(9, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'signatureIsGood'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isCompliant'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyTrust'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'signatureSummary'
        QtMocHelpers::PropertyData<GpgME::Signature::Summary>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SignatureInfo, qt_meta_tag_ZN13SignatureInfoE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignatureInfo::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SignatureInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SignatureInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13SignatureInfoE_t>.metaTypes,
    nullptr
} };

void SignatureInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<SignatureInfo *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->keyId; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->keyMissing; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->keyRevoked; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->keyExpired; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->sigExpired; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->crlMissing; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->crlTooOld; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->signer; break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->signerMailAddresses; break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->signatureIsGood; break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isCompliant; break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->keyTrust; break;
        case 12: *reinterpret_cast<GpgME::Signature::Summary*>(_v) = _t->signatureSummary; break;
        default: break;
        }
    }
}
QT_WARNING_POP
