/****************************************************************************
** Meta object code from reading C++ file 'itinerarymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../mimetreeparser-26.04.2/src/quick/itinerarymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itinerarymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ItineraryModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ItineraryModel::qt_create_metaobjectdata<qt_meta_tag_ZN14ItineraryModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItineraryModel",
        "QML.Element",
        "auto",
        "loaded",
        "",
        "loadErrorOccurred",
        "pathChanged",
        "messageChanged",
        "sendToItinerary",
        "path",
        "message",
        "std::shared_ptr<KMime::Message>",
        "Roles",
        "NameRole",
        "TypeRole",
        "DepartureLocationRole",
        "DepartureTimeRole",
        "DepartureDayRole",
        "DepartureAddressRole",
        "ArrivalLocationRole",
        "ArrivalTimeRole",
        "ArrivalDayRole",
        "ArrivalAddressRole",
        "AddressRole",
        "StartTimeRole",
        "EndTimeRole",
        "DeparturePlatformRole",
        "ArrivalPlatformRole",
        "CoachRole",
        "SeatRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadErrorOccurred'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pathChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'messageChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'sendToItinerary'
        QtMocHelpers::MethodData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'path'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'message'
        QtMocHelpers::PropertyData<std::shared_ptr<KMime::Message>>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(12, 12, QMC::EnumFlags{}).add({
            {   13, Roles::NameRole },
            {   14, Roles::TypeRole },
            {   15, Roles::DepartureLocationRole },
            {   16, Roles::DepartureTimeRole },
            {   17, Roles::DepartureDayRole },
            {   18, Roles::DepartureAddressRole },
            {   19, Roles::ArrivalLocationRole },
            {   20, Roles::ArrivalTimeRole },
            {   21, Roles::ArrivalDayRole },
            {   22, Roles::ArrivalAddressRole },
            {   23, Roles::AddressRole },
            {   24, Roles::StartTimeRole },
            {   25, Roles::EndTimeRole },
            {   26, Roles::DeparturePlatformRole },
            {   27, Roles::ArrivalPlatformRole },
            {   28, Roles::CoachRole },
            {   29, Roles::SeatRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ItineraryModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ItineraryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItineraryModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItineraryModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ItineraryModelE_t>.metaTypes,
    nullptr
} };

void ItineraryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItineraryModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loaded(); break;
        case 1: _t->loadErrorOccurred(); break;
        case 2: _t->pathChanged(); break;
        case 3: _t->messageChanged(); break;
        case 4: _t->sendToItinerary(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItineraryModel::*)()>(_a, &ItineraryModel::loaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItineraryModel::*)()>(_a, &ItineraryModel::loadErrorOccurred, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItineraryModel::*)()>(_a, &ItineraryModel::pathChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItineraryModel::*)()>(_a, &ItineraryModel::messageChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< std::shared_ptr<KMime::Message> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast<std::shared_ptr<KMime::Message>*>(_v) = _t->message(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setMessage(*reinterpret_cast<std::shared_ptr<KMime::Message>*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ItineraryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItineraryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItineraryModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int ItineraryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ItineraryModel::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ItineraryModel::loadErrorOccurred()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ItineraryModel::pathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ItineraryModel::messageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
