/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<itinerarykdeconnecthandler.h>)
#  include <itinerarykdeconnecthandler.h>
#endif
#if __has_include(<itinerarymodel.h>)
#  include <itinerarymodel.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_pim_mimetreeparser()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AttachmentModelForeign>("org.kde.pim.mimetreeparser", 1);
    qmlRegisterTypesAndRevisions<Device>("org.kde.pim.mimetreeparser", 1);
    qmlRegisterTypesAndRevisions<ItineraryKDEConnectHandler>("org.kde.pim.mimetreeparser", 1);
    qmlRegisterTypesAndRevisions<ItineraryModel>("org.kde.pim.mimetreeparser", 1);
    qmlRegisterEnum<ItineraryModel::Roles>("ItineraryModel::Roles");
    qmlRegisterTypesAndRevisions<MessageParserForeign>("org.kde.pim.mimetreeparser", 1);
    qmlRegisterTypesAndRevisions<PartModelForeign>("org.kde.pim.mimetreeparser", 1);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<UrlHandlerForeign>("org.kde.pim.mimetreeparser", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.pim.mimetreeparser", 1, 0);
}

static const QQmlModuleRegistration orgkdepimmimetreeparserRegistration("org.kde.pim.mimetreeparser", qml_register_types_org_kde_pim_mimetreeparser);
