// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "mimetreeparser_core_debug.h"


Q_LOGGING_CATEGORY(MIMETREEPARSER_CORE_LOG, "org.kde.pim.mimetreeparser.core", QtInfoMsg)

