/****************************************************************************
** Meta object code from reading C++ file 'messagepart.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../mimetreeparser-26.04.2/src/core/messagepart.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'messagepart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14MimeTreeParser11MessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::MessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser11MessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::MessagePart",
        "attachment",
        "root",
        "isHtml",
        "plaintextContent",
        "htmlContent"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'attachment'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'root'
        QtMocHelpers::PropertyData<bool>(2, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isHtml'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'plaintextContent'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'htmlContent'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MessagePart, qt_meta_tag_ZN14MimeTreeParser11MessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::MessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser11MessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser11MessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser11MessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::MessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MessagePart *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isAttachment(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isRoot(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isHtml(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->plaintextContent(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->htmlContent(); break;
        default: break;
        }
    }
}

const QMetaObject *MimeTreeParser::MessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::MessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser11MessagePartE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MimeTreeParser::MessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser15MimeMessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::MimeMessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser15MimeMessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::MimeMessagePart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MimeMessagePart, qt_meta_tag_ZN14MimeTreeParser15MimeMessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::MimeMessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15MimeMessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15MimeMessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser15MimeMessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::MimeMessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MimeMessagePart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::MimeMessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::MimeMessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15MimeMessagePartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::MimeMessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser15MessagePartListE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::MessagePartList::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser15MessagePartListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::MessagePartList"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MessagePartList, qt_meta_tag_ZN14MimeTreeParser15MessagePartListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::MessagePartList::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15MessagePartListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15MessagePartListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser15MessagePartListE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::MessagePartList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MessagePartList *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::MessagePartList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::MessagePartList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15MessagePartListE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::MessagePartList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser15TextMessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::TextMessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser15TextMessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::TextMessagePart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TextMessagePart, qt_meta_tag_ZN14MimeTreeParser15TextMessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::TextMessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePartList::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15TextMessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15TextMessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser15TextMessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::TextMessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextMessagePart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::TextMessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::TextMessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15TextMessagePartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePartList::qt_metacast(_clname);
}

int MimeTreeParser::TextMessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePartList::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser21AttachmentMessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::AttachmentMessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser21AttachmentMessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::AttachmentMessagePart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AttachmentMessagePart, qt_meta_tag_ZN14MimeTreeParser21AttachmentMessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::AttachmentMessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<TextMessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser21AttachmentMessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser21AttachmentMessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser21AttachmentMessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::AttachmentMessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttachmentMessagePart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::AttachmentMessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::AttachmentMessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser21AttachmentMessagePartE_t>.strings))
        return static_cast<void*>(this);
    return TextMessagePart::qt_metacast(_clname);
}

int MimeTreeParser::AttachmentMessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TextMessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser15HtmlMessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::HtmlMessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser15HtmlMessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::HtmlMessagePart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HtmlMessagePart, qt_meta_tag_ZN14MimeTreeParser15HtmlMessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::HtmlMessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15HtmlMessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15HtmlMessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser15HtmlMessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::HtmlMessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HtmlMessagePart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::HtmlMessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::HtmlMessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15HtmlMessagePartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::HtmlMessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser22AlternativeMessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::AlternativeMessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser22AlternativeMessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::AlternativeMessagePart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AlternativeMessagePart, qt_meta_tag_ZN14MimeTreeParser22AlternativeMessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::AlternativeMessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser22AlternativeMessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser22AlternativeMessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser22AlternativeMessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::AlternativeMessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AlternativeMessagePart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::AlternativeMessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::AlternativeMessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser22AlternativeMessagePartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::AlternativeMessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser15CertMessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::CertMessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser15CertMessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::CertMessagePart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CertMessagePart, qt_meta_tag_ZN14MimeTreeParser15CertMessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::CertMessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15CertMessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15CertMessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser15CertMessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::CertMessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CertMessagePart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::CertMessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::CertMessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser15CertMessagePartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::CertMessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser29EncapsulatedRfc822MessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::EncapsulatedRfc822MessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser29EncapsulatedRfc822MessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::EncapsulatedRfc822MessagePart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EncapsulatedRfc822MessagePart, qt_meta_tag_ZN14MimeTreeParser29EncapsulatedRfc822MessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::EncapsulatedRfc822MessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser29EncapsulatedRfc822MessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser29EncapsulatedRfc822MessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser29EncapsulatedRfc822MessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::EncapsulatedRfc822MessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EncapsulatedRfc822MessagePart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::EncapsulatedRfc822MessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::EncapsulatedRfc822MessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser29EncapsulatedRfc822MessagePartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::EncapsulatedRfc822MessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser20EncryptedMessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::EncryptedMessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser20EncryptedMessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::EncryptedMessagePart",
        "decryptMessage",
        "isEncrypted",
        "isNoSecKey",
        "passphraseError"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'decryptMessage'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isEncrypted'
        QtMocHelpers::PropertyData<bool>(2, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isNoSecKey'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'passphraseError'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EncryptedMessagePart, qt_meta_tag_ZN14MimeTreeParser20EncryptedMessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::EncryptedMessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser20EncryptedMessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser20EncryptedMessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser20EncryptedMessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::EncryptedMessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EncryptedMessagePart *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->decryptMessage(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isEncrypted(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isNoSecKey(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->passphraseError(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDecryptMessage(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MimeTreeParser::EncryptedMessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::EncryptedMessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser20EncryptedMessagePartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::EncryptedMessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser17SignedMessagePartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::SignedMessagePart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser17SignedMessagePartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::SignedMessagePart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SignedMessagePart, qt_meta_tag_ZN14MimeTreeParser17SignedMessagePartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::SignedMessagePart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser17SignedMessagePartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser17SignedMessagePartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser17SignedMessagePartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::SignedMessagePart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignedMessagePart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::SignedMessagePart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::SignedMessagePart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser17SignedMessagePartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::SignedMessagePart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14MimeTreeParser11HeadersPartE_t {};
} // unnamed namespace

template <> constexpr inline auto MimeTreeParser::HeadersPart::qt_create_metaobjectdata<qt_meta_tag_ZN14MimeTreeParser11HeadersPartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MimeTreeParser::HeadersPart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HeadersPart, qt_meta_tag_ZN14MimeTreeParser11HeadersPartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MimeTreeParser::HeadersPart::staticMetaObject = { {
    QMetaObject::SuperData::link<MessagePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser11HeadersPartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser11HeadersPartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MimeTreeParser11HeadersPartE_t>.metaTypes,
    nullptr
} };

void MimeTreeParser::HeadersPart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HeadersPart *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MimeTreeParser::HeadersPart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MimeTreeParser::HeadersPart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MimeTreeParser11HeadersPartE_t>.strings))
        return static_cast<void*>(this);
    return MessagePart::qt_metacast(_clname);
}

int MimeTreeParser::HeadersPart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessagePart::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
