// SPDX-FileCopyrightText: 2017 Christian Mollekopf <mollekopf@kolabsys.com>
// SPDX-License-Identifier: LGPL-2.0-or-later

#pragma once

#include <QString>

namespace MimeTreeParser
{
[[nodiscard]] QString linkify(const QString &in);
}
