// SPDX-FileCopyrightText: 2016 Sandro Knauß <knauss@kolabsys.com>
// SPDX-License-Identifier: LGPL-2.0-or-later

#include "partmodel.h"

#include "enums.h"
#include "htmlutils.h"
#include "mimetreeparser_core_debug.h"
#include "objecttreeparser.h"
#include "utils.h"

#include <KLocalizedString>
#include <Libkleo/Compliance>
#include <Libkleo/Formatting>
#include <Libkleo/KeyCache>

#include <QDebug>
#include <QGpgME/Protocol>
#include <QRegularExpression>
#include <QStringLiteral>
#include <QTextDocument>

#include <gpgme++/verificationresult.h>
using namespace Qt::Literals::StringLiterals;
static std::optional<GpgME::Signature> signatureFromMessagePart(MimeTreeParser::MessagePart *messagePart)
{
    const auto signatureState = messagePart->signatureState();
    const bool messageIsSigned = signatureState == MimeTreeParser::KMMsgPartiallySigned || signatureState == MimeTreeParser::KMMsgFullySigned;

    if (!messageIsSigned) {
        return std::nullopt;
    }

    const auto signatureParts = messagePart->signatures();
    Q_ASSERT(!signatureParts.isEmpty());
    if (signatureParts.empty()) {
        return std::nullopt;
    }
    const auto signaturePart = signatureParts.front(); // TODO add support for multiple signature

    const auto signatures = signaturePart->partMetaData()->verificationResult.signatures();
    Q_ASSERT(!signatures.empty());
    if (signatures.empty()) {
        return std::nullopt;
    }
    const auto signature = signatures.front(); // TODO add support for multiple signature
    return signature;
}

// We return a pair containing the trimmed string, as well as a boolean indicating whether the string was trimmed or not
std::pair<QString, bool> PartModel::trim(const QString &text)
{
    // The delimiters have <p>.? prefixed including the .? because sometimes we get a byte order mark <feff> (seen with user-agent:
    // Microsoft-MacOutlook/10.1d.0.190908) We match both regulard withspace with \s and non-breaking spaces with \u00A0
    const QList<QRegularExpression> delimiters{
        // English
        QRegularExpression{u"<p>.?-+Original(\\s|\u00A0)Message-+"_s, QRegularExpression::CaseInsensitiveOption},
        // The remainder is not quoted
        QRegularExpression{u"<p>.?On.*wrote:"_s, QRegularExpression::CaseInsensitiveOption},
        // The remainder is quoted
        QRegularExpression{u"&gt; On.*wrote:"_s, QRegularExpression::CaseInsensitiveOption},

        // German
        // Forwarded
        QRegularExpression{u"<p>.?Von:.*</p>"_s, QRegularExpression::CaseInsensitiveOption},
        // Reply
        QRegularExpression{u"<p>.?Am.*schrieb.*:</p>"_s, QRegularExpression::CaseInsensitiveOption},
        // Signature
        QRegularExpression{u"<p>.?--(\\s|\u00A0)<br>"_s, QRegularExpression::CaseInsensitiveOption},
    };

    for (const auto &expression : delimiters) {
        auto i = expression.globalMatchView(text);
        while (i.hasNext()) {
            const auto match = i.next();
            const int startOffset = match.capturedStart(0);
            // This is a very simplistic detection for an inline reply where we would have the patterns before the actual message content.
            // We simply ignore anything we find within the first few lines.
            if (startOffset >= 5) {
                return {text.mid(0, startOffset), true};
            } else {
                // Search for the next delimiter
                continue;
            }
        }
    }

    return {text, false};
}

static QString addCss(const QString &s)
{
    // Get the default font from QApplication
    static const QString fontFamily = QFont{}.family();
    // overflow:hidden ensures no scrollbars are ever shown.
    static const QString css = u"<style>\n"_s
        + QStringLiteral(
              "body {\n"
              "  overflow:hidden;\n"
              "  font-family: \"%1\" ! important;\n"
              "  color: #31363b ! important;\n"
              "  background-color: #fcfcfc ! important\n"
              "}\n")
              .arg(fontFamily)
        + QStringLiteral("blockquote { \n"
                         "  border-left: 2px solid #bdc3c7 ! important;\n"
                         "}\n")
        + u"</style>"_s;

    const QString header = QLatin1StringView(
                               "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n"
                               "<html><head><title></title>")
        + css + QLatin1StringView("</head>\n<body>\n");
    return header + s + u"</body></html>"_s;
}

class PartModelPrivate
{
public:
    PartModelPrivate(PartModel *q_ptr, const std::shared_ptr<MimeTreeParser::ObjectTreeParser> &parser)
        : q(q_ptr)
        , mParser(parser)
    {
        collectContents();
    }

    ~PartModelPrivate() = default;

    void checkPart(const QSharedPointer<MimeTreeParser::MessagePart> part)
    {
        mMimeTypeCache[part.data()] = part->mimeType();
        // Extract the content of the part and
        mContents.insert(part.data(), extractContent(part.data()));
    }

    // Recursively find encapsulated messages
    void findEncapsulated(const QSharedPointer<MimeTreeParser::EncapsulatedRfc822MessagePart> &e)
    {
        mEncapsulatedParts[e.data()] = mParser->collectContentParts(e);
        for (const auto &subPart : std::as_const(mEncapsulatedParts[e.data()])) {
            checkPart(subPart);
            mParents[subPart.data()] = e.data();
            if (auto encapsulatedSub = subPart.dynamicCast<MimeTreeParser::EncapsulatedRfc822MessagePart>()) {
                findEncapsulated(encapsulatedSub);
            }
        }
    }

    QVariant extractContent(MimeTreeParser::MessagePart *messagePart)
    {
        if (auto alternativePart = dynamic_cast<MimeTreeParser::AlternativeMessagePart *>(messagePart)) {
            if (alternativePart->availableModes().contains(MimeTreeParser::AlternativeMessagePart::MultipartIcal)) {
                return alternativePart->icalContent();
            }
        }

        auto preprocessPlaintext = [&](const QString &text) {
            // Reduce consecutive new lines to never exceed 2
            auto cleaned = text;
            cleaned.replace(QRegularExpression(u"[\n\r]{2,}"_s), u"\n\n"_s);

            // We always do rich text (so we get highlighted links and stuff).
            // Show signature in fixed font
            int signature = cleaned.lastIndexOf(u"\n--"_s);
            auto html = Qt::convertFromPlainText(cleaned.left(signature), Qt::WhiteSpaceNormal);
            if (signature > 0) {
                html.append(u"<tt style='white-space:pre-wrap'>%1</tt>"_s.arg(cleaned.mid(signature).replace(u"<"_s, u"&lt;"_s)));
            }

            if (trimMail) {
                const auto result = PartModel::trim(html);
                isTrimmed = result.second;
                Q_EMIT q->trimMailChanged();
                return MimeTreeParser::linkify(result.first);
            }
            return MimeTreeParser::linkify(html);
        };

        if (messagePart->isHtml()) {
            if (dynamic_cast<MimeTreeParser::AlternativeMessagePart *>(messagePart)) {
                containsHtmlAndPlain = true;
                Q_EMIT q->containsHtmlChanged();
                if (!showHtml) {
                    return preprocessPlaintext(messagePart->plaintextContent());
                }
            }
            return addCss(mParser->resolveCidLinks(messagePart->htmlContent()));
        }

        if (auto attachmentPart = dynamic_cast<MimeTreeParser::AttachmentMessagePart *>(messagePart)) {
            auto node = attachmentPart->node();
            if (node && mMimeTypeCache[attachmentPart] == "text/calendar"_ba) {
                return messagePart->text();
            }
        }

        return preprocessPlaintext(messagePart->text());
    }

    QVariant contentForPart(MimeTreeParser::MessagePart *messagePart) const
    {
        return mContents.value(messagePart);
    }

    void collectContents()
    {
        mEncapsulatedParts.clear();
        mParents.clear();
        mContents.clear();
        containsHtmlAndPlain = false;
        isTrimmed = false;

        const auto parts = mParser->collectContentParts();
        QList<QSharedPointer<MimeTreeParser::MessagePart>> filteredParts;

        for (const auto &part : parts) {
            if (part->node()) {
                const auto contentType = part->node()->contentType();
                if (contentType && contentType->hasParameter("protected-headers")) {
                    const auto contentDisposition = part->node()->contentDisposition();
                    if (contentDisposition && contentDisposition->disposition() == KMime::Headers::CDinline) {
                        continue;
                    }
                }
            }

            filteredParts << part;
        }

        for (const auto &part : std::as_const(filteredParts)) {
            checkPart(part);
            if (auto encapsulatedPart = part.dynamicCast<MimeTreeParser::EncapsulatedRfc822MessagePart>()) {
                findEncapsulated(encapsulatedPart);
            }
        }

        for (const auto &part : std::as_const(filteredParts)) {
            if (mMimeTypeCache[part.data()] == "text/calendar"_ba) {
                mParts.prepend(part);
            } else {
                mParts.append(part);
            }
        }
    }

    PartModel *const q;
    QList<QSharedPointer<MimeTreeParser::MessagePart>> mParts;
    QHash<MimeTreeParser::MessagePart *, QByteArray> mMimeTypeCache;
    QHash<MimeTreeParser::MessagePart *, QList<QSharedPointer<MimeTreeParser::MessagePart>>> mEncapsulatedParts;
    QHash<MimeTreeParser::MessagePart *, MimeTreeParser::MessagePart *> mParents;
    QMap<MimeTreeParser::MessagePart *, QVariant> mContents;
    std::shared_ptr<MimeTreeParser::ObjectTreeParser> mParser;
    bool showHtml{false};
    bool containsHtmlAndPlain{false};
    bool trimMail{false};
    bool isTrimmed{false};
};

PartModel::PartModel(std::shared_ptr<MimeTreeParser::ObjectTreeParser> parser)
    : d(std::unique_ptr<PartModelPrivate>(new PartModelPrivate(this, parser)))
{
}

PartModel::~PartModel() = default;

void PartModel::setShowHtml(bool html)
{
    if (d->showHtml != html) {
        beginResetModel();
        d->showHtml = html;
        d->collectContents();
        endResetModel();
        Q_EMIT showHtmlChanged();
    }
}

bool PartModel::showHtml() const
{
    return d->showHtml;
}

void PartModel::setTrimMail(bool trim)
{
    if (d->trimMail != trim) {
        beginResetModel();
        d->trimMail = trim;
        d->collectContents();
        endResetModel();
        Q_EMIT trimMailChanged();
    }
}

bool PartModel::trimMail() const
{
    return d->trimMail;
}

bool PartModel::isTrimmed() const
{
    return d->isTrimmed;
}

bool PartModel::containsHtml() const
{
    return d->containsHtmlAndPlain;
}

QHash<int, QByteArray> PartModel::roleNames() const
{
    return {
        {TypeRole, "type"_ba},
        {ContentRole, "content"_ba},
        {IsEmbeddedRole, "isEmbedded"_ba},
        {SidebarSecurityLevelRole, "sidebarSecurityLevel"_ba},
        {EncryptionSecurityLevelRole, "encryptionSecurityLevel"_ba},
        {SignatureSecurityLevelRole, "signatureSecurityLevel"_ba},
        {EncryptionSecurityLevelRole, "encryptionSecurityLevel"_ba},
        {ErrorType, "errorType"_ba},
        {ErrorString, "errorString"_ba},
        {IsErrorRole, "error"_ba},
        {SenderRole, "sender"_ba},
        {SignatureDetailsRole, "signatureDetails"_ba},
        {SignatureIconNameRole, "signatureIconName"_ba},
        {EncryptionDetails, "encryptionDetails"_ba},
        {EncryptionIconNameRole, "encryptionIconName"_ba},
        {DateRole, "date"_ba},
    };
}

QModelIndex PartModel::index(int row, int column, const QModelIndex &parent) const
{
    if (row < 0 || column != 0) {
        return QModelIndex();
    }
    if (parent.isValid()) {
        const auto part = static_cast<MimeTreeParser::MessagePart *>(parent.internalPointer());
        auto encapsulatedPart = dynamic_cast<MimeTreeParser::EncapsulatedRfc822MessagePart *>(part);

        if (encapsulatedPart) {
            const auto parts = d->mEncapsulatedParts[encapsulatedPart];
            if (row < parts.size()) {
                return createIndex(row, column, parts.at(row).data());
            }
        }
        return QModelIndex();
    }
    if (row < d->mParts.size()) {
        return createIndex(row, column, d->mParts.at(row).data());
    }
    return QModelIndex();
}

SignatureInfo encryptionInfo(MimeTreeParser::MessagePart *messagePart)
{
    SignatureInfo signatureInfo;
    const auto encryptions = messagePart->encryptions();
    if (encryptions.size() > 1) {
        qWarning() << "Can't deal with more than one encryption";
    }
    for (const auto &encryptionPart : encryptions) {
        signatureInfo.keyId = encryptionPart->partMetaData()->keyId;
        signatureInfo.cryptoProto = encryptionPart->cryptoProto();
        signatureInfo.decryptRecipients = encryptionPart->decryptRecipients();
    }
    return signatureInfo;
};
template<typename T>
const T *findHeader(const KMime::Content *content)
{
    if (!content) {
        return {};
    }
    auto header = content->header<T>();
    if (header || !content->parent()) {
        return header;
    }
    return findHeader<T>(content->parent());
}

PartModel::SecurityLevel PartModel::signatureSecurityLevel(MimeTreeParser::MessagePart *messagePart)
{
    auto signature = signatureFromMessagePart(messagePart);
    if (!signature) {
        return SecurityLevel::Unknow;
    }

    const auto summary = signature->summary();

    if (summary & GpgME::Signature::Summary::Red) {
        return SecurityLevel::Bad;
    }
    if (summary & GpgME::Signature::Summary::Valid) {
        return SecurityLevel::Good;
    }

    return SecurityLevel::NotSoGood;
}

QString PartModel::signatureDetails(MimeTreeParser::MessagePart *messagePart)
{
    auto signature = signatureFromMessagePart(messagePart);
    if (!signature) {
        return QString{};
    }

    // guess sender from mime node or parent node
    auto from = findHeader<KMime::Headers::From>(messagePart->node());
    if (from) {
        const auto mailboxes = from->mailboxes();
        if (!mailboxes.isEmpty()) {
            auto mailBox = mailboxes.front();
            if (mailBox.hasAddress()) {
                return Kleo::Formatting::prettySignature(*signature, QString::fromUtf8(mailboxes.front().address()));
            }
        }
    }
    return Kleo::Formatting::prettySignature(*signature, {});
}

QVariant PartModel::data(const QModelIndex &index, int role) const
{
    if (!index.isValid()) {
        return QVariant();
    }

    if (index.internalPointer()) {
        const auto messagePart = static_cast<MimeTreeParser::MessagePart *>(index.internalPointer());
        // qWarning() << "Found message part " << messagePart->metaObject()->className() << messagePart->partMetaData()->status << messagePart->error();
        Q_ASSERT(messagePart);
        switch (role) {
        case Qt::DisplayRole:
            return u"Content%1"_s;
        case SenderRole: {
            if (auto e = dynamic_cast<MimeTreeParser::EncapsulatedRfc822MessagePart *>(messagePart)) {
                return e->from();
            }
            return {};
        }
        case DateRole: {
            if (auto e = dynamic_cast<MimeTreeParser::EncapsulatedRfc822MessagePart *>(messagePart)) {
                return e->date();
            }
            return {};
        }
        case TypeRole: {
            if (messagePart->error()) {
                return QVariant::fromValue(Types::Error);
            }
            if (dynamic_cast<MimeTreeParser::EncapsulatedRfc822MessagePart *>(messagePart)) {
                return QVariant::fromValue(Types::Encapsulated);
            }
            if (auto alternativePart = dynamic_cast<MimeTreeParser::AlternativeMessagePart *>(messagePart)) {
                if (alternativePart->availableModes().contains(MimeTreeParser::AlternativeMessagePart::MultipartIcal)) {
                    return QVariant::fromValue(Types::Ical);
                }
            }
            if (auto attachmentPart = dynamic_cast<MimeTreeParser::AttachmentMessagePart *>(messagePart)) {
                auto node = attachmentPart->node();
                if (!node) {
                    qWarning() << "no content for attachment";
                    return {};
                }
                if (d->mMimeTypeCache[attachmentPart] == "text/calendar"_ba) {
                    return QVariant::fromValue(Types::Ical);
                }
            }
            if (!d->showHtml && d->containsHtmlAndPlain) {
                return QVariant::fromValue(Types::Plain);
            }
            // For simple html we don't need a browser
            auto complexHtml = [&] {
                if (messagePart->isHtml()) {
                    const auto text = messagePart->htmlContent();
                    if (text.contains(u"<!DOCTYPE html PUBLIC"_s)) {
                        // We can probably deal with this if it adheres to the strict dtd
                        //(that's what our composer produces as well)
                        if (!text.contains(u"http://www.w3.org/TR/REC-html40/strict.dtd"_s)) {
                            return true;
                        }
                    }
                    // Blockquotes don't support any styling which would be necessary so they become readable.
                    if (text.contains(u"blockquote"_s)) {
                        return true;
                    }
                    // Media queries are too advanced
                    if (text.contains(u"@media"_s)) {
                        return true;
                    }
                    // auto css properties are not supported e.g margin-left: auto;
                    if (text.contains(u": auto;"_s)) {
                        return true;
                    }
                    return false;
                } else {
                    return false;
                }
            }();
            if (complexHtml) {
                return QVariant::fromValue(Types::Html);
            }
            return QVariant::fromValue(Types::Plain);
        }
        case IsEmbeddedRole:
            return false;
        case IsErrorRole:
            return messagePart->error();
        case ContentRole:
            return d->contentForPart(messagePart);
        case SidebarSecurityLevelRole: {
            const auto signature = index.data(SignatureSecurityLevelRole).value<SecurityLevel>();
            const auto encryption = index.data(EncryptionSecurityLevelRole).value<SecurityLevel>();

            if (signature == SecurityLevel::Bad || encryption == SecurityLevel::Bad) {
                return SecurityLevel::Bad;
            }

            if (signature == SecurityLevel::NotSoGood || encryption == SecurityLevel::NotSoGood) {
                return SecurityLevel::NotSoGood;
            }

            if (signature == SecurityLevel::Good || encryption == SecurityLevel::Good) {
                return SecurityLevel::Good;
            }

            return SecurityLevel::Unknow;
        }
        case SignatureSecurityLevelRole:
            // Color displayed for the signature info box
            return signatureSecurityLevel(messagePart);
        case EncryptionSecurityLevelRole: {
            // Color displayed for the encryption info box
            const auto encryption = messagePart->encryptionState();
            const bool messageIsEncrypted = encryption == MimeTreeParser::KMMsgPartiallyEncrypted || encryption == MimeTreeParser::KMMsgFullyEncrypted;

            if (messagePart->error()) {
                return SecurityLevel::Bad;
            }

            return messageIsEncrypted ? SecurityLevel::Good : SecurityLevel::Unknow;
        }
        case EncryptionIconNameRole: {
            const auto encryption = messagePart->encryptionState();
            const bool messageIsEncrypted = encryption == MimeTreeParser::KMMsgPartiallyEncrypted || encryption == MimeTreeParser::KMMsgFullyEncrypted;

            if (messagePart->error()) {
                return u"data-error"_s;
            }

            return messageIsEncrypted ? u"mail-encrypted"_s : QString();
        }
        case SignatureIconNameRole: {
            auto signature = signatureFromMessagePart(messagePart);
            if (!signature) {
                return QString{};
            }

            const auto summary = signature->summary();
            if (summary & GpgME::Signature::Valid) {
                return u"mail-signed"_s;
            } else if (summary & GpgME::Signature::Red) {
                return u"data-error"_s;
            } else {
                return u"data-warning"_s;
            }
        }
        case SignatureDetailsRole:
            return signatureDetails(messagePart);
        case EncryptionDetails:
            return QVariant::fromValue(encryptionInfo(messagePart));
        case ErrorType:
            return messagePart->error();
        case ErrorString: {
            switch (messagePart->error()) {
            case MimeTreeParser::MessagePart::NoKeyError: {
                if (auto encryptedMessagePart = dynamic_cast<MimeTreeParser::EncryptedMessagePart *>(messagePart)) {
                    if (encryptedMessagePart->isNoSecKey()) {
                        QString errorMessage;
                        if (encryptedMessagePart->cryptoProto() == QGpgME::smime()) {
                            errorMessage += i18ndc("mimetreeparser", "@info:status", "You cannot decrypt this message.");
                        } else {
                            errorMessage += i18ndc("mimetreeparser", "@info:status", "You cannot decrypt this message.");
                        }
                        if (!encryptedMessagePart->decryptRecipients().empty()) {
                            errorMessage += QLatin1Char(' ')
                                + i18ndcp("mimetreeparser",
                                          "@info:status",
                                          "The message is encrypted for the following recipient:",
                                          "The message is encrypted for the following recipients:",
                                          encryptedMessagePart->decryptRecipients().size());
                            errorMessage +=
                                MimeTreeParser::decryptRecipientsToHtml(encryptedMessagePart->decryptRecipients(), encryptedMessagePart->cryptoProto());
                        }
                        return errorMessage;
                    }
                }
            }

                return messagePart->errorString();

            case MimeTreeParser::MessagePart::PassphraseError:
                return i18ndc("mimetreeparser", "@info:status", "Wrong passphrase.");
            case MimeTreeParser::MessagePart::UnknownError:
                break;
            default:
                break;
            }
            return messagePart->errorString();
        }
        }
    }
    return QVariant();
}

QModelIndex PartModel::parent(const QModelIndex &index) const
{
    if (index.isValid()) {
        if (auto indexPart = static_cast<MimeTreeParser::MessagePart *>(index.internalPointer())) {
            for (const auto &part : std::as_const(d->mParts)) {
                if (part.data() == indexPart) {
                    return QModelIndex();
                }
            }
            const auto parentPart = d->mParents[indexPart];
            Q_ASSERT(parentPart);
            int row = 0;
            const auto parts = d->mEncapsulatedParts[parentPart];
            for (const auto &part : parts) {
                if (part.data() == indexPart) {
                    break;
                }
                row++;
            }
            return createIndex(row, 0, parentPart);
        }
        return {};
    }
    return {};
}

int PartModel::rowCount(const QModelIndex &parent) const
{
    if (parent.isValid()) {
        const auto part = static_cast<MimeTreeParser::MessagePart *>(parent.internalPointer());
        auto encapsulatedPart = dynamic_cast<MimeTreeParser::EncapsulatedRfc822MessagePart *>(part);

        if (encapsulatedPart) {
            const auto parts = d->mEncapsulatedParts[encapsulatedPart];
            return parts.size();
        }
        return 0;
    }
    return d->mParts.count();
}

int PartModel::columnCount(const QModelIndex &) const
{
    return 1;
}

#include "moc_partmodel.cpp"
